import os
import tkinter as tk
from tkinter import filedialog, messagebox
import ttkbootstrap as ttk
from ttkbootstrap.constants import *
from PIL import Image, ImageTk
import webbrowser

def download_spotify_playlist():
    playlist_link = spotify_link.get()
    output_folder = folder_path.get()

    if not playlist_link:
        messagebox.showerror("Грешка", "Моля, въведете линк към Spotify плейлист.")
        return
    if not output_folder:
        messagebox.showerror("Грешка", "Моля, изберете папка за запазване на файловете.")
        return

    try:
        os.chdir(output_folder)
        os.system(f'spotdl "{playlist_link}"')
        messagebox.showinfo("Успех", "Плейлистът беше успешно свален.")
    except Exception as e:
        messagebox.showerror("Грешка", f"Грешка при свалянето: {e}")

def download_from_youtube():
    playlist_file = playlist_file_path.get()
    output_folder = folder_path.get()

    if not playlist_file:
        messagebox.showerror("Грешка", "Моля, изберете текстов файл с имената на песните.")
        return
    if not output_folder:
        messagebox.showerror("Грешка", "Моля, изберете папка за запазване на файловете.")
        return

    try:
        with open(playlist_file, 'r', encoding='utf-8') as file:
            songs = file.read().splitlines()
        
        os.chdir(output_folder)
        for song in songs:
            if song.strip():
                os.system(f'yt-dlp --extract-audio --audio-format mp3 "ytsearch:{song}"')
        
        messagebox.showinfo("Успех", "Всички песни бяха успешно свалени.")
    except Exception as e:
        messagebox.showerror("Грешка", f"Грешка при свалянето: {e}")

def download_youtube_video():
    video_link = youtube_video_link.get()
    output_folder = folder_path.get()

    if not video_link:
        messagebox.showerror("Грешка", "Моля, въведете линк към YouTube видеото.")
        return
    if not output_folder:
        messagebox.showerror("Грешка", "Моля, изберете папка за запазване на файловете.")
        return

    try:
        os.chdir(output_folder)
        os.system(f'yt-dlp -f best "{video_link}"')
        messagebox.showinfo("Успех", "Видеото беше успешно свалено.")
    except Exception as e:
        messagebox.showerror("Грешка", f"Грешка при свалянето: {e}")

# Създаване на GUI
root = ttk.Window(themename="cosmo")
root.title("Сваляне на плейлист")
root.geometry("620x320")
root.resizable(False, False)

# Поле за избор на текстов файл с имената на песните
ttk.Label(root, text="Изберете текстов файл с имената на песните:").grid(row=0, column=0, padx=10, pady=5, sticky="w")
playlist_file_path = ttk.StringVar()
ttk.Entry(root, textvariable=playlist_file_path, width=40, state='readonly').grid(row=0, column=1, padx=5, pady=5)
ttk.Button(root, text="Избери", command=lambda: playlist_file_path.set(filedialog.askopenfilename(filetypes=[("Text files", "*.txt")])), bootstyle=PRIMARY).grid(row=0, column=2, padx=5, pady=5)

# Поле за въвеждане на линк към Spotify плейлист
ttk.Label(root, text="Въведете линк към Spotify плейлист:").grid(row=1, column=0, padx=10, pady=5, sticky="w")
spotify_link = ttk.Entry(root, width=40)
spotify_link.grid(row=1, column=1, padx=5, pady=5)
ttk.Button(root, text="Постави", command=lambda: spotify_link.insert(0, root.clipboard_get()), bootstyle=PRIMARY).grid(row=1, column=2, padx=5, pady=5)

# Поле за избор на папка за запазване
ttk.Label(root, text="Изберете папка за запазване на файловете:").grid(row=2, column=0, padx=10, pady=5, sticky="w")
folder_path = ttk.StringVar()
ttk.Entry(root, textvariable=folder_path, width=40).grid(row=2, column=1, padx=5, pady=5)
ttk.Button(root, text="Избери", command=lambda: folder_path.set(filedialog.askdirectory()), bootstyle=PRIMARY).grid(row=2, column=2, padx=5, pady=5)

# Поле за въвеждане на линк към YouTube видео
ttk.Label(root, text="Въведете линк към YouTube видео:").grid(row=3, column=0, padx=10, pady=5, sticky="w")
youtube_video_link = ttk.Entry(root, width=40)
youtube_video_link.grid(row=3, column=1, padx=5, pady=5)
ttk.Button(root, text="Постави", command=lambda: youtube_video_link.insert(0, root.clipboard_get()), bootstyle=PRIMARY).grid(row=3, column=2, padx=5, pady=5)

# Бутон за сваляне от Spotify
ttk.Button(root, text="Свали плейлист от Spotify", command=download_spotify_playlist, bootstyle=SUCCESS).grid(row=4, column=0, columnspan=3, pady=5)

# Бутон за сваляне от YouTube като MP3
ttk.Button(root, text="Свали плейлист от YouTube (MP3)", command=download_from_youtube, bootstyle=INFO).grid(row=5, column=0, columnspan=3, pady=5)

# Бутон за сваляне на видео
ttk.Button(root, text="Свали YouTube видео (MP4)", command=download_youtube_video, bootstyle=WARNING).grid(row=6, column=0, columnspan=3, pady=5)

# Етикет с текст за информация
def open_link():
    webbrowser.open("https://urocibg.eu/%f0%9f%8e%b5-spotify-%d0%b8-youtube-playlist-downloader/")

link_button = ttk.Button(root, text="Посетете сайта приложението", command=open_link, bootstyle=LINK)
link_button.grid(row=9, column=0, columnspan=3, pady=5)


# Стартиране на приложението
root.mainloop()
